==> kubernetes-model-1.0.54-sources.jar: annotations/io/fabric8/openshift/api/model/DeploymentTriggerPolicyBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.util.Set;
import java.lang.Object;

public class DeploymentTriggerPolicyBuilder extends DeploymentTriggerPolicyFluentImpl<DeploymentTriggerPolicyBuilder> implements VisitableBuilder<DeploymentTriggerPolicy,DeploymentTriggerPolicyBuilder>{

    DeploymentTriggerPolicyFluent<?> fluent;
    Boolean validationEnabled;

    public DeploymentTriggerPolicyBuilder(){
            this(true);
    }
    public DeploymentTriggerPolicyBuilder(Boolean validationEnabled){
            this(new DeploymentTriggerPolicy(), validationEnabled);
    }
    public DeploymentTriggerPolicyBuilder(DeploymentTriggerPolicyFluent<?> fluent){
            this(fluent, true);
    }
    public DeploymentTriggerPolicyBuilder(DeploymentTriggerPolicyFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new DeploymentTriggerPolicy(), validationEnabled);
    }
    public DeploymentTriggerPolicyBuilder(DeploymentTriggerPolicyFluent<?> fluent,DeploymentTriggerPolicy instance){
            this(fluent, instance, true);
    }
    public DeploymentTriggerPolicyBuilder(DeploymentTriggerPolicyFluent<?> fluent,DeploymentTriggerPolicy instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withImageChangeParams(instance.getImageChangeParams()); 
            fluent.withType(instance.getType()); 
            this.validationEnabled = validationEnabled; 
    }
    public DeploymentTriggerPolicyBuilder(DeploymentTriggerPolicy instance){
            this(instance,true);
    }
    public DeploymentTriggerPolicyBuilder(DeploymentTriggerPolicy instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withImageChangeParams(instance.getImageChangeParams()); 
            this.withType(instance.getType()); 
            this.validationEnabled = validationEnabled; 
    }

    public DeploymentTriggerPolicy build(){
            DeploymentTriggerPolicy buildable = new DeploymentTriggerPolicy(fluent.getImageChangeParams(),fluent.getType());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            DeploymentTriggerPolicyBuilder that = (DeploymentTriggerPolicyBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-1.0.64-sources.jar: annotations/io/fabric8/openshift/api/model/DeploymentTriggerPolicyBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import javax.annotation.Generated;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;

public class DeploymentTriggerPolicyBuilder extends DeploymentTriggerPolicyFluentImpl<DeploymentTriggerPolicyBuilder> implements VisitableBuilder<DeploymentTriggerPolicy,DeploymentTriggerPolicyBuilder>{

    DeploymentTriggerPolicyFluent<?> fluent;
    Boolean validationEnabled;

    public DeploymentTriggerPolicyBuilder(){
            this(true);
    }
    public DeploymentTriggerPolicyBuilder(Boolean validationEnabled){
            this(new DeploymentTriggerPolicy(), validationEnabled);
    }
    public DeploymentTriggerPolicyBuilder(DeploymentTriggerPolicyFluent<?> fluent){
            this(fluent, true);
    }
    public DeploymentTriggerPolicyBuilder(DeploymentTriggerPolicyFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new DeploymentTriggerPolicy(), validationEnabled);
    }
    public DeploymentTriggerPolicyBuilder(DeploymentTriggerPolicyFluent<?> fluent,DeploymentTriggerPolicy instance){
            this(fluent, instance, true);
    }
    public DeploymentTriggerPolicyBuilder(DeploymentTriggerPolicyFluent<?> fluent,DeploymentTriggerPolicy instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withImageChangeParams(instance.getImageChangeParams()); 
            fluent.withType(instance.getType()); 
            this.validationEnabled = validationEnabled; 
    }
    public DeploymentTriggerPolicyBuilder(DeploymentTriggerPolicy instance){
            this(instance,true);
    }
    public DeploymentTriggerPolicyBuilder(DeploymentTriggerPolicy instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withImageChangeParams(instance.getImageChangeParams()); 
            this.withType(instance.getType()); 
            this.validationEnabled = validationEnabled; 
    }

    public DeploymentTriggerPolicy build(){
            DeploymentTriggerPolicy buildable = new DeploymentTriggerPolicy(fluent.getImageChangeParams(),fluent.getType());
            io.fabric8.kubernetes.api.builder.ValidationUtils.validate(buildable);
            return buildable;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            DeploymentTriggerPolicyBuilder that = (DeploymentTriggerPolicyBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
